

<div>

{% for route in routes %}
  <div class="route">

    <h3 id="{{ route.name }}" class="route-path">
      <code>{{ route.path }}</code>
      <a class="permalink" href="#{{ route.name|urlencode }}">#</a>
    </h3>
    <div class="route-details">
      {% if route.summary %}
        <h4 class="route-summary">{{ route.summary }}</h4>
      {% endif %}

      {% if route.description %}
        <div class="route-description">{{ route.description|markdown|safe }}</div>
      {% endif %}

      <div class="route-usage">
        <h4>Usage</h4>
        <code>{{ route.usage }}</code>
      </div>
      <!-- Body params -->
      {% with name = "Arguments", description = "Place these in your Tableau calculation after the script path, in the listed order.", params = route.body_params, ordered = True %}
        {% include "param_table.html" %}
      {% endwith %}
      <!-- Query params -->
      {% if route.query_params %}
        {% with name = "Query Parameters", description = "Place these at the end of the script path, preceded by `?` and separated by `&`, as in `/path?param1=green&param2=42`.", params = route.query_params %}
          {% include "param_table.html" %}
        {% endwith %}
      {% endif %}
      </div>


      {% if route.return and route.returns.description %}
        <div>
          <h4>Return value</h4>
          <table class="items">
            <tr>
              <th>Type</th>
              <th>Description</th>
            </tr>
            <tr>
              <td class="item-type">{{ route.returns.type|default("(Not specified)", true) }}</td>
              <td class="item-desc">{{ route.returns.description }}</td>
            </tr>
          </table>
        </div>

    </div>

  {% endif %}
</div>
{% endfor %}

        
      </div>
