/*User Guide Styles*/

@charset "UTF-8";
html {
    box-sizing: border-box;
    -webkit-text-size-adjust: none;
    -ms-text-size-adjust: none;
    text-size-adjust: none
}

*,
:after,
:before {
    box-sizing: inherit
}

body {
    margin: 0
}

a,
button,
input,
label {
    -webkit-tap-highlight-color: transparent
}

a {
    color: inherit;
    text-decoration: none
}

img {
    border-style: none
}

body {
    color: var(--md-typeset-color)
}

.route code,
.warning-container code,
.indented-detail code,
input,
kbd,
pre {
    color: var(--md-typeset-color);
    font-feature-settings: "kern";
    font-family: ui-monospace,SFMono-Regular,SF Mono,Menlo,Consolas,Liberation Mono,monospace;
    padding: .2em .4em;
    border-radius: 6px;
    font-size: 85%;
    word-break: break-word;
    background-color: var(--md-code-bg-color);
    -webkit-box-decoration-break: clone;
    box-decoration-break: clone
}

.explain p {
    margin-top:  -1.6em;
    /*padding: .2em .4em;*/
    /*border-radius: 6px;*/
    font-style: italic;
    font-size: 95%;
    /*background-color: var(--md-code-bg-color);*/
}

:root {
    --md-default-fg-color: rgba(0, 0, 0, 0.87);
    --md-default-fg-color--light: rgba(0, 0, 0, 0.54);
    --md-default-fg-color--lighter: rgba(0, 0, 0, 0.32);
    --md-default-fg-color--lightest: rgba(0, 0, 0, 0.07);
    --md-default-bg-color: #fff;
    --md-default-bg-color--light: hsla(0, 0%, 100%, 0.7);
    --md-default-bg-color--lighter: hsla(0, 0%, 100%, 0.3);
    --md-default-bg-color--lightest: hsla(0, 0%, 100%, 0.12);
    --md-primary-fg-color: #4051b5;
    --md-primary-fg-color--light: #5d6cc0;
    --md-primary-fg-color--dark: #303fa1;
    --md-primary-bg-color: #fff;
    --md-primary-bg-color--light: hsla(0, 0%, 100%, 0.7);
    --md-accent-fg-color: #526cfe;
    --md-accent-fg-color--transparent: rgba(83, 108, 254, 0.1);
    --md-accent-bg-color: #fff;
    --md-accent-bg-color--light: hsla(0, 0%, 100%, 0.7)
}

:root>* {
    --md-code-fg-color: #24292f;
    --md-code-bg-color: rgba(175,184,193,0.2);
    --md-code-hl-color: rgba(255, 255, 0, 0.5);
    --md-code-hl-number-color: #d52a2a;
    --md-code-hl-special-color: #db1457;
    --md-code-hl-function-color: #a846b9;
    --md-code-hl-constant-color: #6e59d9;
    --md-code-hl-keyword-color: #3f6ec6;
    --md-code-hl-string-color: #1c7d4d;
    --md-code-hl-name-color: var(--md-code-fg-color);
    --md-code-hl-operator-color: var(--md-default-fg-color--light);
    --md-code-hl-punctuation-color: var(--md-default-fg-color--light);
    --md-code-hl-comment-color: var(--md-default-fg-color--light);
    --md-code-hl-generic-color: var(--md-default-fg-color--light);
    --md-code-hl-variable-color: var(--md-default-fg-color--light);
    --md-typeset-color: var(--md-default-fg-color);
    --md-typeset-a-color: var(--md-primary-fg-color);
    --md-typeset-mark-color: rgba(255, 255, 0, 0.5);
    --md-typeset-del-color: rgba(245, 80, 61, 0.15);
    --md-typeset-ins-color: rgba(11, 213, 112, 0.15);
    --md-typeset-kbd-color: #fafafa;
    --md-typeset-kbd-accent-color: #fff;
    --md-typeset-kbd-border-color: #b8b8b8;
    --md-admonition-fg-color: var(--md-default-fg-color);
    --md-admonition-bg-color: var(--md-default-bg-color);
    --md-footer-fg-color: #fff;
    --md-footer-fg-color--light: hsla(0, 0%, 100%, 0.7);
    --md-footer-fg-color--lighter: hsla(0, 0%, 100%, 0.3);
    --md-footer-bg-color: rgba(0, 0, 0, 0.87);
    --md-footer-bg-color--dark: rgba(0, 0, 0, 0.32)
}

.md-icon svg {
    display: block;
    width: 1.2rem;
    height: 1.2rem;
    fill: currentColor
}

body,
input {
    font-feature-settings: "kern", "liga";
    font-family: var(--md-text-font-family, _), -apple-system, BlinkMacSystemFont, Helvetica, Arial, sans-serif
}

:root {
    --md-typeset-table--ascending: url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'><path d='M11 4h2v12l5.5-5.5 1.42 1.42L12 19.84l-7.92-7.92L5.5 10.5 11 16V4z'/></svg>");
    --md-typeset-table--descending: url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'><path d='M13 20h-2V8l-5.5 5.5-1.42-1.42L12 4.16l7.92 7.92-1.42 1.42L13 8v12z'/></svg>")
}

.md-typeset {
    font-size: .8rem;
    line-height: 1.6;
    -webkit-print-color-adjust: exact;
    color-adjust: exact
}

.md-typeset blockquote,
.md-typeset dl,
.md-typeset figure,
.md-typeset ol,
.md-typeset pre,
.md-typeset ul {
    margin: 1em 0
}

.md-typeset h1 {
    margin: 0 0 1.25em
    /*line-height:1.3;*/
    font-size: 36px;
}

.md-typeset h1,
.md-typeset h2 {
}

.md-typeset h2 {
    /*margin: 1.6em 0em;*/
    font-size: 1.5625em;
    line-height: 1.4
}

.md-typeset h3 {
    /*margin: 1.6em 0em;*/
    font-weight: bold;
    font-size: 1.25em;
    line-height: 1.5;
}

.md-typeset h4 {
    /*margin: 1em 0;*/
    font-weight: 700;
}

.md-typeset a {
    color: var(--md-typeset-a-color);
    word-break: break-word
}

.md-typeset a,
.md-typeset a:before {
    transition: color 125ms
}

.md-typeset a:focus,
.md-typeset a:hover {
    color: var(--md-accent-fg-color)
}

.md-typeset ul {
    list-style-type: disc
}

.md-typeset ol,
.md-typeset ul {
    margin-left: .625em;
    padding: 0
}

.md-typeset ol li,
.md-typeset ul li {
    /*margin-bottom: .5em;*/
    margin-left: 1.25em
}

.md-typeset ol li:last-child,
.md-typeset ul li:last-child {
    margin-bottom: 0
}

.md-typeset img,
.md-typeset svg {
    max-width: 100%;
    height: auto
}

.md-typeset code,
.md-typeset kbd,
.md-typeset pre {
    color: var(--md-code-fg-color);
    direction: ltr
}

@media print {
    .md-typeset code,
    .md-typeset kbd,
    .md-typeset pre {
        white-space: pre-wrap
    }
}

html {
    height: 100%;
    overflow-x: hidden;
    font-size: 125%
}

body {
    position: relative;
    display: flex;
    flex-direction: column;
    width: 100%;
    min-height: 100%;
    font-size: .5rem;
    background-color: var(--md-default-bg-color)
}

/* .md-grid {
    max-width: 61rem;
    margin-right: auto;
    margin-left: auto
} */

.md-container {
    display: flex;
    flex-direction: column;
    flex-grow: 1
}

.md-main {
    flex-grow: 1
}

.md-main__inner {
    display: flex;
    height: 100%;
}

.md-ellipsis {
    overflow: hidden;
    white-space: nowrap;
    text-overflow: ellipsis
}

:root {
    --md-clipboard-icon: url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'><path d='M19 21H8V7h11m0-2H8a2 2 0 0 0-2 2v14a2 2 0 0 0 2 2h11a2 2 0 0 0 2-2V7a2 2 0 0 0-2-2m-3-4H4a2 2 0 0 0-2 2v14h2V3h12V1z'/></svg>")
}

.md-content {
    flex-grow: 1;
    overflow: hidden;
    scroll-padding-top: 51.2rem
}

.md-content__inner {
    margin: 0 .8rem 1.2rem 20px;
    padding-top: .6rem;
    max-width: 710px
}

.md-content__inner:before {
    display: block;
    height: .4rem;
    content: ""
}

.md-content__inner>:last-child {
    margin-bottom: 0
}

.md-header {
    position: -webkit-sticky;
    position: sticky;
    top: 0;
    right: 0;
    left: 0;
    z-index: 2;
    color: var(--md-primary-bg-color);
    background-color: var(--md-primary-fg-color);
    box-shadow: 0 0 .2rem transparent, 0 .2rem .4rem transparent
}

.md-header[data-md-state=shadow] {
    box-shadow: 0 0 .2rem rgba(0, 0, 0, .1), 0 .2rem .4rem rgba(0, 0, 0, .2);
    transition: transform .25s cubic-bezier(.1, .7, .1, 1), box-shadow .25s
}

.md-header__inner {
    display: flex;
    align-items: center;
    padding: 0 .2rem
}

.md-header__button {
    position: relative;
    z-index: 1;
    margin: .2rem;
    padding: .4rem;
    color: currentColor;
    vertical-align: middle;
    outline-color: var(--md-accent-fg-color);
    cursor: pointer;
    transition: opacity .25s
}

.md-header__button:hover {
    opacity: .7
}

.md-header__button:not([hidden]) {
    display: inline-block
}

.md-header__button:not(.focus-visible) {
    outline: none;
    -webkit-tap-highlight-color: transparent
}

.md-header__topic {
    position: absolute;
    display: flex;
    max-width: 100%;
    transition: transform .4s cubic-bezier(.1, .7, .1, 1), opacity .15s
}

.md-header__title {
    flex-grow: 1;
    height: 2.4rem;
    margin-right: .4rem;
    font-size: .9rem;
    line-height: 2.4rem
}

.md-header__title>.md-header__ellipsis {
    position: relative;
    width: 100%;
    height: 100%
}

:root {
    --md-nav-icon--prev: url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'><path d='M20 11v2H8l5.5 5.5-1.42 1.42L4.16 12l7.92-7.92L13.5 5.5 8 11h12z'/></svg>");
    --md-nav-icon--next: url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'><path d='M8.59 16.58 13.17 12 8.59 7.41 10 6l6 6-6 6-1.41-1.42z'/></svg>");
    --md-toc-icon: url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'><path d='M3 9h14V7H3v2m0 4h14v-2H3v2m0 4h14v-2H3v2m16 0h2v-2h-2v2m0-10v2h2V7h-2m0 6h2v-2h-2v2z'/></svg>")
}

:root {
    --md-search-result-icon: url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'><path d='M14 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h7c-.41-.25-.8-.56-1.14-.9-.33-.33-.61-.7-.86-1.1H6V4h7v5h5v1.18c.71.16 1.39.43 2 .82V8l-6-6m6.31 16.9c1.33-2.11.69-4.9-1.4-6.22-2.11-1.33-4.91-.68-6.22 1.4-1.34 2.11-.69 4.89 1.4 6.22 1.46.93 3.32.93 4.79.02L22 23.39 23.39 22l-3.08-3.1m-3.81.1a2.5 2.5 0 0 1-2.5-2.5 2.5 2.5 0 0 1 2.5-2.5 2.5 2.5 0 0 1 2.5 2.5 2.5 2.5 0 0 1-2.5 2.5z'/></svg>")
}

:root {
    --md-source-forks-icon: url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16'><path fill-rule='evenodd' d='M5 3.25a.75.75 0 1 1-1.5 0 .75.75 0 0 1 1.5 0zm0 2.122a2.25 2.25 0 1 0-1.5 0v.878A2.25 2.25 0 0 0 5.75 8.5h1.5v2.128a2.251 2.251 0 1 0 1.5 0V8.5h1.5a2.25 2.25 0 0 0 2.25-2.25v-.878a2.25 2.25 0 1 0-1.5 0v.878a.75.75 0 0 1-.75.75h-4.5A.75.75 0 0 1 5 6.25v-.878zm3.75 7.378a.75.75 0 1 1-1.5 0 .75.75 0 0 1 1.5 0zm3-8.75a.75.75 0 1 0 0-1.5.75.75 0 0 0 0 1.5z'/></svg>");
    --md-source-repositories-icon: url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16'><path fill-rule='evenodd' d='M2 2.5A2.5 2.5 0 0 1 4.5 0h8.75a.75.75 0 0 1 .75.75v12.5a.75.75 0 0 1-.75.75h-2.5a.75.75 0 1 1 0-1.5h1.75v-2h-8a1 1 0 0 0-.714 1.7.75.75 0 0 1-1.072 1.05A2.495 2.495 0 0 1 2 11.5v-9zm10.5-1V9h-8c-.356 0-.694.074-1 .208V2.5a1 1 0 0 1 1-1h8zM5 12.25v3.25a.25.25 0 0 0 .4.2l1.45-1.087a.25.25 0 0 1 .3 0L8.6 15.7a.25.25 0 0 0 .4-.2v-3.25a.25.25 0 0 0-.25-.25h-3.5a.25.25 0 0 0-.25.25z'/></svg>");
    --md-source-stars-icon: url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16'><path fill-rule='evenodd' d='M8 .25a.75.75 0 0 1 .673.418l1.882 3.815 4.21.612a.75.75 0 0 1 .416 1.279l-3.046 2.97.719 4.192a.75.75 0 0 1-1.088.791L8 12.347l-3.766 1.98a.75.75 0 0 1-1.088-.79l.72-4.194L.818 6.374a.75.75 0 0 1 .416-1.28l4.21-.611L7.327.668A.75.75 0 0 1 8 .25zm0 2.445L6.615 5.5a.75.75 0 0 1-.564.41l-3.097.45 2.24 2.184a.75.75 0 0 1 .216.664l-.528 3.084 2.769-1.456a.75.75 0 0 1 .698 0l2.77 1.456-.53-3.084a.75.75 0 0 1 .216-.664l2.24-2.183-3.096-.45a.75.75 0 0 1-.564-.41L8 2.694v.001z'/></svg>");
    --md-source-version-icon: url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16'><path fill-rule='evenodd' d='M2.5 7.775V2.75a.25.25 0 0 1 .25-.25h5.025a.25.25 0 0 1 .177.073l6.25 6.25a.25.25 0 0 1 0 .354l-5.025 5.025a.25.25 0 0 1-.354 0l-6.25-6.25a.25.25 0 0 1-.073-.177zm-1.5 0V2.75C1 1.784 1.784 1 2.75 1h5.025c.464 0 .91.184 1.238.513l6.25 6.25a1.75 1.75 0 0 1 0 2.474l-5.026 5.026a1.75 1.75 0 0 1-2.474 0l-6.25-6.25A1.75 1.75 0 0 1 1 7.775zM6 5a1 1 0 1 0 0 2 1 1 0 0 0 0-2z'/></svg>")
}

:root {
    --md-version-icon: url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 320 512'><path d='M31.3 192h257.3c17.8 0 26.7 21.5 14.1 34.1L174.1 354.8c-7.8 7.8-20.5 7.8-28.3 0L17.2 226.1C4.6 213.5 13.5 192 31.3 192z'/></svg>")
}

:root {
    --md-admonition-icon--note: url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'><path d='M20.71 7.04c.39-.39.39-1.04 0-1.41l-2.34-2.34c-.37-.39-1.02-.39-1.41 0l-1.84 1.83 3.75 3.75M3 17.25V21h3.75L17.81 9.93l-3.75-3.75L3 17.25z'/></svg>");
    --md-admonition-icon--abstract: url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'><path d='M4 5h16v2H4V5m0 4h16v2H4V9m0 4h16v2H4v-2m0 4h10v2H4v-2z'/></svg>");
    --md-admonition-icon--info: url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'><path d='M13 9h-2V7h2m0 10h-2v-6h2m-1-9A10 10 0 0 0 2 12a10 10 0 0 0 10 10 10 10 0 0 0 10-10A10 10 0 0 0 12 2z'/></svg>");
    --md-admonition-icon--tip: url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'><path d='M17.66 11.2c-.23-.3-.51-.56-.77-.82-.67-.6-1.43-1.03-2.07-1.66C13.33 7.26 13 4.85 13.95 3c-.95.23-1.78.75-2.49 1.32-2.59 2.08-3.61 5.75-2.39 8.9.04.1.08.2.08.33 0 .22-.15.42-.35.5-.23.1-.47.04-.66-.12a.58.58 0 0 1-.14-.17c-1.13-1.43-1.31-3.48-.55-5.12C5.78 10 4.87 12.3 5 14.47c.06.5.12 1 .29 1.5.14.6.41 1.2.71 1.73 1.08 1.73 2.95 2.97 4.96 3.22 2.14.27 4.43-.12 6.07-1.6 1.83-1.66 2.47-4.32 1.53-6.6l-.13-.26c-.21-.46-.77-1.26-.77-1.26m-3.16 6.3c-.28.24-.74.5-1.1.6-1.12.4-2.24-.16-2.9-.82 1.19-.28 1.9-1.16 2.11-2.05.17-.8-.15-1.46-.28-2.23-.12-.74-.1-1.37.17-2.06.19.38.39.76.63 1.06.77 1 1.98 1.44 2.24 2.8.04.14.06.28.06.43.03.82-.33 1.72-.93 2.27z'/></svg>");
    --md-admonition-icon--success: url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'><path d='M12 2C6.5 2 2 6.5 2 12s4.5 10 10 10 10-4.5 10-10S17.5 2 12 2m-2 15-5-5 1.41-1.41L10 14.17l7.59-7.59L19 8l-9 9z'/></svg>");
    --md-admonition-icon--question: url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'><path d='m15.07 11.25-.9.92C13.45 12.89 13 13.5 13 15h-2v-.5c0-1.11.45-2.11 1.17-2.83l1.24-1.26c.37-.36.59-.86.59-1.41a2 2 0 0 0-2-2 2 2 0 0 0-2 2H8a4 4 0 0 1 4-4 4 4 0 0 1 4 4 3.2 3.2 0 0 1-.93 2.25M13 19h-2v-2h2M12 2A10 10 0 0 0 2 12a10 10 0 0 0 10 10 10 10 0 0 0 10-10c0-5.53-4.5-10-10-10z'/></svg>");
    --md-admonition-icon--warning: url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'><path d='M13 14h-2V9h2m0 9h-2v-2h2M1 21h22L12 2 1 21z'/></svg>");
    --md-admonition-icon--failure: url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'><path d='M12 2c5.53 0 10 4.47 10 10s-4.47 10-10 10S2 17.53 2 12 6.47 2 12 2m3.59 5L12 10.59 8.41 7 7 8.41 10.59 12 7 15.59 8.41 17 12 13.41 15.59 17 17 15.59 13.41 12 17 8.41 15.59 7z'/></svg>");
    --md-admonition-icon--danger: url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'><path d='m11.5 20 4.86-9.73H13V4l-5 9.73h3.5V20M12 2c2.75 0 5.1 1 7.05 2.95C21 6.9 22 9.25 22 12s-1 5.1-2.95 7.05C17.1 21 14.75 22 12 22s-5.1-1-7.05-2.95C3 17.1 2 14.75 2 12s1-5.1 2.95-7.05C6.9 3 9.25 2 12 2z'/></svg>");
    --md-admonition-icon--bug: url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'><path d='M14 12h-4v-2h4m0 6h-4v-2h4m6-6h-2.81a5.985 5.985 0 0 0-1.82-1.96L17 4.41 15.59 3l-2.17 2.17a6.002 6.002 0 0 0-2.83 0L8.41 3 7 4.41l1.62 1.63C7.88 6.55 7.26 7.22 6.81 8H4v2h2.09c-.05.33-.09.66-.09 1v1H4v2h2v1c0 .34.04.67.09 1H4v2h2.81c1.04 1.79 2.97 3 5.19 3s4.15-1.21 5.19-3H20v-2h-2.09c.05-.33.09-.66.09-1v-1h2v-2h-2v-1c0-.34-.04-.67-.09-1H20V8z'/></svg>");
    --md-admonition-icon--example: url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'><path d='M7 13v-2h14v2H7m0 6v-2h14v2H7M7 7V5h14v2H7M3 8V5H2V4h2v4H3m-1 9v-1h3v4H2v-1h2v-.5H3v-1h1V17H2m2.25-7a.75.75 0 0 1 .75.75c0 .2-.08.39-.21.52L3.12 13H5v1H2v-.92L4 11H2v-1h2.25z'/></svg>");
    --md-admonition-icon--quote: url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'><path d='M14 17h3l2-4V7h-6v6h3M6 17h3l2-4V7H5v6h3l-2 4z'/></svg>")
}

:root {
    --md-footnotes-icon: url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'><path d='M19 7v4H5.83l3.58-3.59L8 6l-6 6 6 6 1.41-1.42L5.83 13H21V7h-2z'/></svg>")
}

:root {
    --md-details-icon: url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'><path d='M8.59 16.58 13.17 12 8.59 7.41 10 6l6 6-6 6-1.41-1.42z'/></svg>")
}

:root {
    --md-tasklist-icon: url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'><path fill-rule='evenodd' d='M1 12C1 5.925 5.925 1 12 1s11 4.925 11 11-4.925 11-11 11S1 18.075 1 12zm16.28-2.72a.75.75 0 0 0-1.06-1.06l-5.97 5.97-2.47-2.47a.75.75 0 0 0-1.06 1.06l3 3a.75.75 0 0 0 1.06 0l6.5-6.5z'/></svg>");
    --md-tasklist-icon--checked: url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'><path fill-rule='evenodd' d='M1 12C1 5.925 5.925 1 12 1s11 4.925 11 11-4.925 11-11 11S1 18.075 1 12zm16.28-2.72a.75.75 0 0 0-1.06-1.06l-5.97 5.97-2.47-2.47a.75.75 0 0 0-1.06 1.06l3 3a.75.75 0 0 0 1.06 0l6.5-6.5z'/></svg>")
}

.md-header[data-md-state=shadow] {
    transition: background-color 0s;
    box-shadow: none
}

.md-header {
    border-bottom: 1px solid rgba(0, 0, 0, .15) !important
}

h2.divider {
    text-align: left;
    max-width: 650px;
    margin: 1em 0 .64em
}

.feature-list {
    list-style: none;
    padding: 15px 0 0 0;
    margin: 0;
    font-size: 0;
}

.feature-list li.item {
    display: inline-block;
    background: #fff;
    border-radius: 15px;
    vertical-align: top;
    width: 200px;
    min-width: 200px;
    height: 250px;
    padding: 0;
    margin: 0 10px;
    box-shadow: 0 1px 5px rgba(0, 0, 0, .2)
}

.feature-btn {
    display: block;
    height: 100%;
    width: 100%;
    text-align: center;
    position: relative;
    border-radius: 15px
}

.aligner {
    display: -webkit-box;
    display: -webkit-flex;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-align: center;
    -webkit-align-items: center;
    -ms-flex-align: center;
    align-items: center;
    min-height: 24em;
    -webkit-box-pack: center;
    -webkit-justify-content: center;
    -ms-flex-pack: center;
    justify-content: center
}

.aligner-item {
    -webkit-box-flex: 1;
    -webkit-flex: 1;
    -ms-flex: 1;
    flex: 1
}

.aligner-item--fixed {
    -webkit-box-flex: 0;
    -webkit-flex: none;
    -ms-flex: none;
    flex: none;
    max-width: 100%
}

.feature-btn .front {
    width: 100%;
    padding: 0 10px
}

.feature-btn .front img {
    height: 40px
}

.feature-btn .front h3 {
    font-size: 16px;
    color: #222b37;
    font-weight: bold;
    line-height: 22px;
    margin: 20px 0 0
}

.feature-btn .front h4 {
    font-size: 14px;
    color: var(--md-default-fg-color--light);
    line-height: 20px;
    margin: 20px 0 0
}

.feature-btn:hover {
    color: rgba(255, 255, 255, 1);
    box-shadow: 0 5px 15px rgba(145, 92, 182, .4);
}

.aligner {
    display: -webkit-box;
    display: -webkit-flex;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-align: center;
    -webkit-align-items: center;
    -ms-flex-align: center;
    align-items: center;
    min-height: 24em;
    -webkit-box-pack: center;
    -webkit-justify-content: center;
    -ms-flex-pack: center;
    justify-content: center
}

.aligner-item {
    -webkit-box-flex: 1;
    -webkit-flex: 1;
    -ms-flex: 1;
    flex: 1
}

.aligner-item--fixed {
    -webkit-box-flex: 0;
    -webkit-flex: none;
    -ms-flex: none;
    flex: none;
    max-width: 100%
}

.api-desc {
  margin-top: 0;
}

table.items {
  border-spacing: 1px;
  border-collapse: collapse;
  width: 100%;
}

table.items th {
  text-align: left;
}

table.items th, table.items td {
  padding: 3px;
  border: 1px solid #EEE;
}

td.item-name {
  width: 25%;
}

td.item-type {
  width: 25%;
}

td.item-desc {
  width: 50%;
}


.small-button {
  background: #7d8492;
  border-radius: 57px;
  display: inline-block;
  font-size: 10px;
  margin: 0 0 0 5px;
  padding: 2px 4px;
  position: relative;
  top: -5px;
  vertical-align: super;
  opacity: .75;
}

.version {
  color: #fff;
  font-family: sans-serif;
  margin: 0;
  padding: 0;
  font-size: 14px;
  margin-left: 5px;
  margin-right: 5px;
}

.swagger-container {
  margin-top: -1.5rem;
}

.tableau-usage-container {
  margin-top: -2rem;
}

.warning-container {
  /*color: black;*/
  background-color: antiquewhite;
  padding: 0.4em 0.4em;
  border-radius: 6px;
}

.indented-detail {
  margin: 0 0 0 2rem;
}

.pill {
    color: var(--md-typeset-color);
    font-feature-settings: "kern";
    padding: .2em .4em;
    border-radius: 6px;
    font-size: 85%;
    word-break: break-word;
    background-color: var(--md-code-bg-color);
    -webkit-box-decoration-break: clone;
    box-decoration-break: clone
}

.route-details {
  margin-left: 2rem;
  margin-bottom: 2rem;
}

.nav-bar {
  width: 100%;
  display: flex;
  align-items: center;
  padding: 0 0.2rem;
}
